@@ -5,7 +5,6 @@ Main GUI for iris
 
 from os.path import dirname, join
 from pathlib import Path
-from shutil import copy2
 
 import pyqtgraph as pg
 from PyQt5 import QtCore, QtGui, QtWidgets
@@ -15,7 +14,7 @@ from skued import diffread
 # Get all proper subclasses of AbstractRawDataset
 # to build a loading menu
 from .. import AbstractRawDataset, __version__, __author__, __license__
-from ..plugins import PLUGIN_DIR
+from ..plugins import PLUGIN_DIR, install_plugin
 from .angular_average_dialog import AngularAverageDialog
 from .calibrate_q_dialog import QCalibratorDialog
 from .control_bar import ControlBar
@@ -29,6 +28,13 @@ from .symmetrize_dialog import SymmetrizeDialog
 
 image_folder = join(dirname(__file__), 'images')
 
+LOAD_PLUGIN_HELP = """You will be prompted to select a plug-in file. This file will be COPIED into:
+
+{dir}
+
+Once this is done, iris will have to restart. 
+The plug-in will remain installed as long as it can be found in the above directory"""
+
 class Iris(QtWidgets.QMainWindow, metaclass = ErrorAware):
     
     dataset_path_signal             = QtCore.pyqtSignal(str)
@@ -227,23 +233,23 @@ class Iris(QtWidgets.QMainWindow, metaclass = ErrorAware):
 
         self.diffraction_dataset_menu = self.menu_bar.addMenu('&Dataset')
         self.diffraction_dataset_menu.addAction(self.processing_action)
+        self.diffraction_dataset_menu.addSeparator()
+        self.diffraction_dataset_menu.addAction(self.update_metadata_action)
         self.diffraction_dataset_menu.addAction(self.symmetrize_action)
         self.diffraction_dataset_menu.addAction(self.promote_to_powder_action)
-        self.diffraction_dataset_menu.addAction(self.recompute_angular_averages)
-        self.diffraction_dataset_menu.addAction(self.update_metadata_action)
         self.diffraction_dataset_menu.addSeparator()
+        self.diffraction_dataset_menu.addAction(self.recompute_angular_averages)
+        self.diffraction_dataset_menu.addAction(self.calibrate_scattvector_action)
 
         # Display options
-        self.diffraction_dataset_display_options_menu = self.diffraction_dataset_menu.addMenu('& Diffraction display options')
+
+        self.display_options_menu = self.menu_bar.addMenu('&Display')
+        self.diffraction_dataset_display_options_menu = self.display_options_menu.addMenu('& Diffraction display options')
         self.controller.processed_dataset_loaded_signal.connect(self.diffraction_dataset_display_options_menu.setEnabled)
 
-        self.powder_dataset_display_options_menu = self.diffraction_dataset_menu.addMenu('& Powder display options')
+        self.powder_dataset_display_options_menu = self.display_options_menu.addMenu('& Powder display options')
         self.controller.powder_dataset_loaded_signal.connect(self.powder_dataset_display_options_menu.setEnabled)
 
-        # Others
-        self.diffraction_dataset_menu.addSeparator()
-        self.diffraction_dataset_menu.addAction(self.calibrate_scattvector_action)
-
         # Assemble submenus
         self.diffraction_dataset_display_options_menu.addAction(self.show_diff_peak_dynamics_action)
         self.diffraction_dataset_display_options_menu.addAction(self.show_diff_relative_action)
@@ -388,18 +394,9 @@ class Iris(QtWidgets.QMainWindow, metaclass = ErrorAware):
     
     @QtCore.pyqtSlot()
     def load_single_picture(self):
-        # Distinguish between skued 1.0.1.0 and skued 1.0.0.0
-        # TODO: once minimum version is skued 1.0.1.0, change this
-        try:
-            from skued import dmread
-        except ImportError:
-            formats = 'Images (*.tif *.tiff *.mib)'
-        else:
-            formats = 'Images (*.tif *.tiff *.mib *.dm3 *.dm4)'
-
         path = self.file_dialog.getOpenFileName(parent = self, 
                                                 caption = 'Load diffraction picture', 
-                                                filter = formats)[0]
+                                                filter = 'Images (*.tif *.tiff *.mib *.dm3 *.dm4)')[0]
         if not path:
             return
 
@@ -427,12 +424,7 @@ class Iris(QtWidgets.QMainWindow, metaclass = ErrorAware):
     @QtCore.pyqtSlot()
     def load_plugin(self):
         """ Load plug-in and restart application. """
-        explanation = """You will be prompted to select a plug-in file. This file will be COPIED into:
-
-        {dir}
-
-        Once this is done, iris will have to restart. The plug-in will remain installed as long as it can be found 
-        in the above directory""".format(dir = PLUGIN_DIR)
+        explanation = LOAD_PLUGIN_HELP.format(dir = PLUGIN_DIR)
 
         QtWidgets.QMessageBox.information(self, 'Loading a plug-in', explanation)
 
@@ -440,9 +432,7 @@ class Iris(QtWidgets.QMainWindow, metaclass = ErrorAware):
         if not path:
             return
         
-        path = Path(path)
-        
-        copy2(path, PLUGIN_DIR / path.name)
+        install_plugin(path)
 
         self.controller.close_dataset()
         self.controller.close_raw_dataset()
